<?php

namespace Drupal\entity_information;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides common methods and injects services for core selection handlers.
 */
trait EntityInformationHelperTrait {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * Wraps the entity type manager.
   *
   * @return \Drupal\Core\Entity\EntityTypeManagerInterface
   *   The module handler.
   */
  public function entityTypeManager(): EntityTypeManagerInterface {
    if (property_exists($this, 'entityTypeManager') && $this->moduleHandler instanceof EntityTypeManagerInterface) {
      return $this->entityTypeManager;
    }

    return \Drupal::service('entity_type.manager');
  }

  /**
   * Wraps the module handler.
   *
   * @return \Drupal\Core\Extension\ModuleHandlerInterface
   *   The module handler.
   */
  public function moduleHandler(): ModuleHandlerInterface {
    if (property_exists($this, 'moduleHandler') && $this->entityTypeManager instanceof ModuleHandlerInterface) {
      return $this->moduleHandler;
    }

    return \Drupal::service('module_handler');
  }

/**
 * Wraps the current user.
 *
 * @return \Drupal\Core\Session\AccountInterface
 *   The current user.
 */
public function currentUser(): AccountInterface {
  if (property_exists($this, 'currentUser') && $this->currentUser instanceof AccountInterface) {
    return $this->currentUser;
  }

  return \Drupal::service('current_user');
}

}
