<?php

namespace Drupal\entity_information\Plugin;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\Routing\RedirectDestinationTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\entity_information\EntityInformationHelperTrait;

/**
 * Base class for Entity information plugins.
 */
abstract class EntityInformationBase extends PluginBase {

  use EntityInformationHelperTrait;
  use StringTranslationTrait;
  use RedirectDestinationTrait;

  /**
   * A message explaining why no results are found.
   *
   * @var string
   */
  protected $noResultsMessage = '';

  /**
   * Gets the message explaining why no results are found.
   *
   * @return string
   *   The message explaining why no results are found.
   */
  public function getNoResultsMessage(): string {
    return $this->noResultsMessage;
  }

  /**
   * Sets the message explaining why no results are found.
   *
   * @param string $no_results_message
   *   The message explaining why no results are found.
   */
  public function setNoResultsMessage(string $no_results_message): void {
    $this->noResultsMessage = $no_results_message;
  }

  /**
   * Returns the message when no results are found.
   *
   * @return array
   */
  public function noResultsResponse(): array {
    return [
      '#markup' => $this->getNoResultsMessage(),
    ];
  }

}
